=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2013-01-18 16:59:54 +0000
+++ CMakeLists.txt	2013-02-11 22:41:12 +0000
@@ -234,6 +234,7 @@
   add_subdirectory(plugins/unitydialog)
   add_subdirectory(plugins/unity-mt-grab-handles)
   add_subdirectory(shortcuts)
+  add_subdirectory(shutdown)
   add_subdirectory(unity-standalone)
 endif ()
 

=== added file 'resources/hibernate.png'
Binary files resources/hibernate.png and resources/hibernate.png differ
=== added file 'resources/hibernate_highlight.png'
Binary files resources/hibernate_highlight.png and resources/hibernate_highlight.png differ
=== added file 'resources/lockscreen.png'
Binary files resources/lockscreen.png and resources/lockscreen.png differ
=== added file 'resources/lockscreen_highlight.png'
Binary files resources/lockscreen_highlight.png and resources/lockscreen_highlight.png differ
=== added file 'resources/restart.png'
Binary files resources/restart.png and resources/restart.png differ
=== added file 'resources/restart_highlight.png'
Binary files resources/restart_highlight.png and resources/restart_highlight.png differ
=== added file 'resources/shutdown.png'
Binary files resources/shutdown.png and resources/shutdown.png differ
=== added file 'resources/shutdown_highlight.png'
Binary files resources/shutdown_highlight.png and resources/shutdown_highlight.png differ
=== added file 'resources/suspend.png'
Binary files resources/suspend.png and resources/suspend.png differ
=== added file 'resources/suspend_highlight.png'
Binary files resources/suspend_highlight.png and resources/suspend_highlight.png differ
=== added directory 'shutdown'
=== added file 'shutdown/CMakeLists.txt'
--- shutdown/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ shutdown/CMakeLists.txt	2013-02-11 22:41:12 +0000
@@ -0,0 +1,34 @@
+set(UNITY_SRC ../plugins/unityshell/src)
+
+set (CFLAGS
+     ${CACHED_UNITY_DEPS_CFLAGS}
+     ${CACHED_UNITY_DEPS_CFLAGS_OTHER}
+     ${PIC_FLAGS}
+     )
+
+string (REPLACE ";" " " CFLAGS "${CFLAGS}")
+set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} ${CFLAGS}")
+
+set (LIBS ${CACHED_UNITY_DEPS_LDFLAGS} ${UNITY_STANDALONE_LADD})
+
+include_directories (.. ../services ../UnityCore ${UNITY_SRC} ${CMAKE_BINARY_DIR})
+
+#
+# Headers & Sources
+#
+set (SHUTDOWN_SOURCES
+     SessionController.cpp
+     SessionController.h
+     SessionView.cpp
+     SessionView.h
+     )
+
+add_library (shutdown-lib STATIC ${SHUTDOWN_SOURCES})
+add_dependencies (shutdown-lib unity-core-${UNITY_API_VERSION} unity-shared)
+add_pch(pch/shutdown_pch.hh shutdown-lib)
+
+#
+# Standalone variant
+#
+add_executable (shutdown StandaloneSession.cpp)
+target_link_libraries (shutdown shutdown-lib unity-shared)

=== added file 'shutdown/SessionController.cpp'
--- shutdown/SessionController.cpp	1970-01-01 00:00:00 +0000
+++ shutdown/SessionController.cpp	2013-02-11 22:41:12 +0000
@@ -0,0 +1,168 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Marco Trevisan (Treviño) <marco@ubuntu.com>
+*/
+
+#include "SessionController.h"
+
+#include "unity-shared/UBusMessages.h"
+#include "unity-shared/UScreen.h"
+
+namespace na = nux::animation;
+
+namespace unity
+{
+namespace session
+{
+namespace
+{
+const unsigned int FADE_DURATION = 100;
+}
+
+Controller::Controller(session::Manager::Ptr const& manager)
+  : manager_(manager)
+  , bg_color_(0.0, 0.0, 0.0, 0.5)
+  , fade_animator_(FADE_DURATION)
+{
+  ubus_manager_.RegisterInterest(UBUS_BACKGROUND_COLOR_CHANGED,
+                                 sigc::mem_fun(this, &Controller::OnBackgroundUpdate));
+
+  ubus_manager_.SendMessage(UBUS_BACKGROUND_REQUEST_COLOUR_EMIT);
+
+  fade_animator_.updated.connect([this] (double opacity) {
+    if (!view_window_)
+      return;
+
+    view_window_->SetOpacity(opacity);
+
+    if (opacity == 0.0f && fade_animator_.GetFinishValue() == 0.0f)
+      CloseWindow();
+  });
+}
+
+void Controller::OnBackgroundUpdate(GVariant* data)
+{
+  gdouble red, green, blue, alpha;
+  g_variant_get(data, "(dddd)", &red, &green, &blue, &alpha);
+  bg_color_ = nux::Color(red, green, blue, alpha);
+
+  if (view_)
+    view_->background_color = bg_color_;
+}
+
+void Controller::Show()
+{
+  EnsureView();
+
+  view_->SetupBackground(true);
+
+  int monitor = UScreen::GetDefault()->GetMonitorWithMouse();
+  auto const& offset = GetOffsetPerMonitor(monitor);
+  view_window_->SetXY(offset.x, offset.y);
+  view_window_->EnableInputWindow(true, view_window_->GetWindowName().c_str(), true, false);
+  view_window_->ShowWindow(true);
+  view_window_->PushToFront();
+
+  if (fade_animator_.CurrentState() == na::Animation::State::Running)
+  {
+    if (fade_animator_.GetFinishValue() == 0.0f)
+      fade_animator_.Reverse();
+  }
+  else
+  {
+    fade_animator_.SetStartValue(0.0f).SetFinishValue(1.0f).Start();
+  }
+}
+
+nux::Point Controller::GetOffsetPerMonitor(int monitor)
+{
+  EnsureView();
+
+  // view_window_->ComputeContentSize();
+  auto const& view_geo = view_->GetAbsoluteGeometry();
+  auto const& monitor_geo = UScreen::GetDefault()->GetMonitorGeometry(monitor);
+
+  //TODO get adjustment from windowmanager!
+  nux::Point offset(adjustment_.x + monitor_geo.x, adjustment_.y + monitor_geo.y);
+  offset.x += (monitor_geo.width - view_geo.width - adjustment_.x) / 2;
+  offset.y += (monitor_geo.height - view_geo.height - adjustment_.y) / 2;
+
+  return offset;
+}
+
+void Controller::ConstructView()
+{
+  view_ = View::Ptr(new View(manager_));
+  view_->SetupBackground(false);
+  view_->background_color = bg_color_;
+  AddChild(view_.GetPointer());
+
+  auto layout = new nux::HLayout(NUX_TRACKER_LOCATION);
+  layout->SetVerticalExternalMargin(0);
+  layout->SetHorizontalExternalMargin(0);
+  layout->AddView(view_.GetPointer());
+
+  view_window_ = new nux::BaseWindow("SessionManager");
+  view_window_->SetLayout(layout);
+  view_window_->SetBackgroundColor(nux::color::Transparent);
+  view_window_->SetWindowSizeMatchLayout(true);
+  view_window_->ShowWindow(false);
+}
+
+void Controller::EnsureView()
+{
+  if (!view_window_)
+    ConstructView();
+}
+
+void Controller::Hide()
+{
+  if (fade_animator_.CurrentState() == na::Animation::State::Running)
+  {
+    if (fade_animator_.GetFinishValue() == 1.0f)
+      fade_animator_.Reverse();
+  }
+  else
+  {
+    fade_animator_.SetStartValue(1.0f).SetFinishValue(0.0f).Start();
+  }
+}
+
+void Controller::CloseWindow()
+{
+  view_window_->PushToBack();
+  view_window_->ShowWindow(false);
+  view_window_->EnableInputWindow(false);
+  view_->SetupBackground(false);
+}
+
+//
+// Introspection
+//
+std::string Controller::GetName() const
+{
+  return "ShutdownController";
+}
+
+void Controller::AddProperties(GVariantBuilder* builder)
+{
+  unity::variant::BuilderWrapper(builder)
+  .add("visible", (view_window_ && view_window_->GetOpacity() == 1.0f));
+}
+
+} // namespace session
+} // namespace unity

=== added file 'shutdown/SessionController.h'
--- shutdown/SessionController.h	1970-01-01 00:00:00 +0000
+++ shutdown/SessionController.h	2013-02-11 22:41:12 +0000
@@ -0,0 +1,81 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Marco Trevisan (Treviño) <marco@ubuntu.com>
+*/
+
+#ifndef UNITYSHELL_SESSION_CONTROLLER_H
+#define UNITYSHELL_SESSION_CONTROLLER_H
+
+#include <memory>
+
+#include <Nux/Nux.h>
+#include <Nux/BaseWindow.h>
+#include <Nux/HLayout.h>
+#include <NuxCore/Color.h>
+#include <NuxCore/Animation.h>
+#include <UnityCore/SessionManager.h>
+
+#include "SessionView.h"
+#include "unity-shared/Introspectable.h"
+#include "unity-shared/UBusWrapper.h"
+
+namespace unity
+{
+namespace session
+{
+
+class Controller : public debug::Introspectable
+{
+public:
+  typedef std::shared_ptr<Controller> Ptr;
+
+  Controller(session::Manager::Ptr const& manager);
+  virtual ~Controller() = default;
+
+  void Show();
+  void Hide();
+
+  bool Visible() const;
+
+protected:
+  // Introspectable
+  std::string GetName() const;
+  void AddProperties(GVariantBuilder* builder);
+
+  virtual nux::Point GetOffsetPerMonitor(int monitor);
+
+private:
+  void ConstructView();
+  void EnsureView();
+  void CloseWindow();
+  void OnBackgroundUpdate(GVariant* data);
+
+  View::Ptr view_;
+  nux::ObjectPtr<nux::BaseWindow> view_window_;
+  nux::Point adjustment_;
+  session::Manager::Ptr manager_;
+
+  nux::Color bg_color_;
+
+  nux::animation::AnimateValue<double> fade_animator_;
+  UBusManager ubus_manager_;
+};
+
+}
+}
+
+#endif

=== added file 'shutdown/SessionView.cpp'
--- shutdown/SessionView.cpp	1970-01-01 00:00:00 +0000
+++ shutdown/SessionView.cpp	2013-02-11 22:41:12 +0000
@@ -0,0 +1,67 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Marco Trevisan (Treviño) <marco@ubuntu.com>
+*/
+
+#include "SessionView.h"
+
+#include <Nux/VLayout.h>
+#include <UnityCore/GLibWrapper.h>
+#include <glib/gi18n-lib.h>
+#include "unity-shared/StaticCairoText.h"
+
+namespace unity
+{
+namespace session
+{
+NUX_IMPLEMENT_OBJECT_TYPE(View);
+
+View::View(Manager::Ptr const& manager)
+  : manager_(manager)
+{
+  closable = true;
+  auto main_layout = new nux::VLayout();
+  int offset = style()->GetInternalOffset();
+  main_layout->SetPadding(offset + 20, offset + 28);
+  SetLayout(main_layout);
+
+  auto header = glib::String(g_strdup_printf(_("Goodbye %s! Would you like to…"), manager->RealName().c_str())).Str();
+  auto* header_view = new StaticCairoText(header);
+  header_view->SetFont("Ubuntu Light 12");
+  main_layout->AddView(header_view, 1 , nux::MINOR_POSITION_CENTER, nux::MINOR_SIZE_FULL);
+}
+
+nux::Geometry View::GetBackgroundGeometry()
+{
+  return GetGeometry();
+}
+
+void View::DrawOverlay(nux::GraphicsEngine& GfxContext, bool force_draw, nux::Geometry clip)
+{
+  view_layout_->ProcessDraw(GfxContext, force_draw);
+}
+
+//
+// Introspectable methods
+//
+std::string View::GetName() const
+{
+  return "SessionView";
+}
+
+} // namespace session
+} // namespace unity

=== added file 'shutdown/SessionView.h'
--- shutdown/SessionView.h	1970-01-01 00:00:00 +0000
+++ shutdown/SessionView.h	2013-02-11 22:41:12 +0000
@@ -0,0 +1,57 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Marco Trevisan (Treviño) <marco@ubuntu.com>
+*/
+
+#ifndef UNITYSHELL_SESSION_VIEW_H
+#define UNITYSHELL_SESSION_VIEW_H
+
+#include <Nux/Nux.h>
+#include <Nux/View.h>
+
+#include "unity-shared/UnityWindowView.h"
+
+namespace unity
+{
+namespace session
+{
+
+class View : public ui::UnityWindowView
+{
+  NUX_DECLARE_OBJECT_TYPE(View, ui::UnityWindowView);
+public:
+  typedef nux::ObjectPtr<View> Ptr;
+
+  View(Manager::Ptr const& manager);
+
+protected:
+  void DrawOverlay(nux::GraphicsEngine& GfxContext, bool force_draw, nux::Geometry clip);
+  nux::Geometry GetBackgroundGeometry();
+
+  // Introspectable methods
+  std::string GetName() const;
+
+private:
+  Manager::Ptr manager_;
+};
+
+} // namespace session
+
+} // namespace unity
+
+#endif // UNITYSHELL_SESSION_VIEW_H
+

=== added file 'shutdown/StandaloneSession.cpp'
--- shutdown/StandaloneSession.cpp	1970-01-01 00:00:00 +0000
+++ shutdown/StandaloneSession.cpp	2013-02-11 22:41:12 +0000
@@ -0,0 +1,121 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2013 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Marco Trevisan <marco@ubuntu.com>
+ */
+
+#include "config.h"
+#include <glib/gi18n-lib.h>
+#include <gtk/gtk.h>
+#include <Nux/Nux.h>
+#include <Nux/NuxTimerTickSource.h>
+#include <Nux/WindowThread.h>
+#include <NuxCore/AnimationController.h>
+#include <UnityCore/SessionManager.h>
+
+#include "unity-shared/BackgroundEffectHelper.h"
+#include "SessionController.h"
+#include "unity-shared/UnitySettings.h"
+
+using namespace unity;
+
+class MockSessionManager : public session::Manager
+{
+public:
+  MockSessionManager() = default;
+
+  std::string RealName() const { return "Marco Trevisan"; }
+  std::string UserName() const { return "marco"; }
+
+  void Logout() { std::cout << "Logout" << std::endl; }
+  void Reboot() { std::cout << "Reboot" << std::endl; }
+  void Shutdown() { std::cout << "Shutdown" << std::endl; }
+  void Suspend() { std::cout << "Suspend" << std::endl; }
+  void Hibernate() { std::cout << "Hibernate" << std::endl; }
+
+  void ConfirmLogout() { std::cout << "ConfirmLogout" << std::endl; }
+  void ConfirmReboot() { std::cout << "ConfirmReboot" << std::endl; }
+  void ConfirmShutdown() { std::cout << "ConfirmShutdown" << std::endl; }
+  void CancelAction() { std::cout << "CancelAction" << std::endl; }
+  void ClosedDialog() { std::cout << "ClosedDialog" << std::endl; }
+
+  bool CanShutdown() const {return true;}
+  bool CanSuspend() const {return true;}
+  bool CanHibernate() const {return false;}
+};
+
+namespace unity
+{
+namespace session
+{
+struct StandaloneController : Controller
+{
+  StandaloneController(session::Manager::Ptr const& manager)
+    : Controller(manager)
+  {}
+
+  nux::Point GetOffsetPerMonitor(int monitor) override
+  {
+    return nux::Point();
+  }
+};
+}
+}
+
+struct SessionWindow
+{
+  SessionWindow()
+    : wt(nux::CreateGUIThread("Unity Session Controller", 1024, 300, 0, &SessionWindow::ThreadWidgetInit, this))
+    , animation_controller(tick_source)
+  {}
+
+  void Show()
+  {
+    wt->Run(nullptr);
+  }
+
+private:
+  void Init();
+
+  static void ThreadWidgetInit(nux::NThread* thread, void* self)
+  {
+    static_cast<SessionWindow*>(self)->Init();
+  }
+
+  unity::Settings settings;
+  std::shared_ptr<nux::WindowThread> wt;
+  nux::NuxTimerTickSource tick_source;
+  nux::animation::AnimationController animation_controller;
+  session::Controller::Ptr controller;
+};
+
+void SessionWindow::Init()
+{
+  BackgroundEffectHelper::blur_type = BLUR_NONE;
+  auto manager = std::make_shared<MockSessionManager>();
+  controller = std::make_shared<session::StandaloneController>(manager);
+  controller->Show();
+}
+
+int main(int argc, char** argv)
+{
+  gtk_init(&argc, &argv);
+
+  nux::NuxInitialize(0);
+  SessionWindow().Show();
+
+  return 0;
+}

=== added directory 'shutdown/pch'
=== added file 'shutdown/pch/shutdown_pch.hh'
--- shutdown/pch/shutdown_pch.hh	1970-01-01 00:00:00 +0000
+++ shutdown/pch/shutdown_pch.hh	2013-02-11 22:41:12 +0000
@@ -0,0 +1,28 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2012 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Jussi Pakkanen <jussi.pakkanen@canonical.com>
+ */
+
+/*
+ * These are the precompiled header includes for this module.
+ * Only system header files can be listed here.
+ */
+
+#include <memory>
+
+#include <Nux/Nux.h>
+#include <UnityCore/GnomeSessionManager.h>

=== modified file 'unity-shared/UnityWindowStyle.cpp'
--- unity-shared/UnityWindowStyle.cpp	2013-02-10 23:02:14 +0000
+++ unity-shared/UnityWindowStyle.cpp	2013-02-11 22:41:12 +0000
@@ -42,7 +42,7 @@
 
 int UnityWindowStyle::GetCloseButtonPadding() const
 {
-  return 2;
+  return 4;
 }
 
 UnityWindowStyle::BaseTexturePtr UnityWindowStyle::GetCloseIcon()

=== modified file 'unity-shared/UnityWindowView.cpp'
--- unity-shared/UnityWindowView.cpp	2013-02-10 23:02:53 +0000
+++ unity-shared/UnityWindowView.cpp	2013-02-11 22:41:12 +0000
@@ -66,10 +66,13 @@
   close_button_->SetSize(texture->GetWidth(), texture->GetHeight());
   close_button_->SetBaseXY(padding, padding);
 
-  close_button_->mouse_click.connect([this](int, int, unsigned long, unsigned long)
-  {
+  close_button_->SetParentObject(this);   
+
+  close_button_->mouse_down.connect([this](int, int, unsigned long, unsigned long) { QueueDraw(); });
+  close_button_->mouse_up.connect([this](int, int, unsigned long, unsigned long) { QueueDraw(); });
+
+  close_button_->mouse_click.connect([this](int, int, unsigned long, unsigned long) {
     request_close.emit();
-    QueueDraw();
   });
 }
 

